"""
Setup script for types-aioboto3-lite.

Copyright 2024 Vlad Emelianov
"""

from pathlib import Path

from setuptools import setup  # type: ignore

LONG_DESCRIPTION = (Path(__file__).parent / "README.md").read_text()


setup(
    name="types-aioboto3-lite",
    version="13.3.0",
    packages=["aioboto3-stubs"],
    url="https://github.com/youtype/mypy_boto3_builder",
    license="MIT License",
    author="Vlad Emelianov",
    author_email="vlad.emelianov.nz@gmail.com",
    description="Lite type annotations for aioboto3 13.3.0 generated with mypy-boto3-builder 8.7.0",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Environment :: Console",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: English",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Programming Language :: Python :: 3.13",
        "Programming Language :: Python :: 3.14",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: Implementation :: CPython",
        "Typing :: Stubs Only",
    ],
    keywords="aioboto3 aioboto3-stubs type-annotations typeshed autocomplete",
    long_description=LONG_DESCRIPTION,
    long_description_content_type="text/markdown",
    package_data={"aioboto3-stubs": ["py.typed", "*.pyi", "*/*.pyi"]},
    python_requires=">=3.8",
    project_urls={
        "Documentation": "https://youtype.github.io/types_aioboto3_docs/",
        "Source": "https://github.com/youtype/mypy_boto3_builder",
        "Tracker": "https://github.com/youtype/mypy_boto3_builder/issues",
    },
    install_requires=[
        "botocore-stubs",
        "types-aiobotocore-lite",
        "types-s3transfer",
        'typing-extensions>=4.1.0; python_version<"3.12"',
    ],
    extras_require={
        "full": ["types-aiobotocore-full>=13.3.0, <13.4.0"],
        "aioboto3": ["aioboto3==13.3.0"],
        "all": [
            "types-aiobotocore-accessanalyzer>=13.3.0, <13.4.0",
            "types-aiobotocore-account>=13.3.0, <13.4.0",
            "types-aiobotocore-acm>=13.3.0, <13.4.0",
            "types-aiobotocore-acm-pca>=13.3.0, <13.4.0",
            "types-aiobotocore-amp>=13.3.0, <13.4.0",
            "types-aiobotocore-amplify>=13.3.0, <13.4.0",
            "types-aiobotocore-amplifybackend>=13.3.0, <13.4.0",
            "types-aiobotocore-amplifyuibuilder>=13.3.0, <13.4.0",
            "types-aiobotocore-apigateway>=13.3.0, <13.4.0",
            "types-aiobotocore-apigatewaymanagementapi>=13.3.0, <13.4.0",
            "types-aiobotocore-apigatewayv2>=13.3.0, <13.4.0",
            "types-aiobotocore-appconfig>=13.3.0, <13.4.0",
            "types-aiobotocore-appconfigdata>=13.3.0, <13.4.0",
            "types-aiobotocore-appfabric>=13.3.0, <13.4.0",
            "types-aiobotocore-appflow>=13.3.0, <13.4.0",
            "types-aiobotocore-appintegrations>=13.3.0, <13.4.0",
            "types-aiobotocore-application-autoscaling>=13.3.0, <13.4.0",
            "types-aiobotocore-application-insights>=13.3.0, <13.4.0",
            "types-aiobotocore-application-signals>=13.3.0, <13.4.0",
            "types-aiobotocore-applicationcostprofiler>=13.3.0, <13.4.0",
            "types-aiobotocore-appmesh>=13.3.0, <13.4.0",
            "types-aiobotocore-apprunner>=13.3.0, <13.4.0",
            "types-aiobotocore-appstream>=13.3.0, <13.4.0",
            "types-aiobotocore-appsync>=13.3.0, <13.4.0",
            "types-aiobotocore-apptest>=13.3.0, <13.4.0",
            "types-aiobotocore-arc-zonal-shift>=13.3.0, <13.4.0",
            "types-aiobotocore-artifact>=13.3.0, <13.4.0",
            "types-aiobotocore-athena>=13.3.0, <13.4.0",
            "types-aiobotocore-auditmanager>=13.3.0, <13.4.0",
            "types-aiobotocore-autoscaling>=13.3.0, <13.4.0",
            "types-aiobotocore-autoscaling-plans>=13.3.0, <13.4.0",
            "types-aiobotocore-b2bi>=13.3.0, <13.4.0",
            "types-aiobotocore-backup>=13.3.0, <13.4.0",
            "types-aiobotocore-backup-gateway>=13.3.0, <13.4.0",
            "types-aiobotocore-batch>=13.3.0, <13.4.0",
            "types-aiobotocore-bcm-data-exports>=13.3.0, <13.4.0",
            "types-aiobotocore-bcm-pricing-calculator>=13.3.0, <13.4.0",
            "types-aiobotocore-bedrock>=13.3.0, <13.4.0",
            "types-aiobotocore-bedrock-agent>=13.3.0, <13.4.0",
            "types-aiobotocore-bedrock-agent-runtime>=13.3.0, <13.4.0",
            "types-aiobotocore-bedrock-data-automation>=13.3.0, <13.4.0",
            "types-aiobotocore-bedrock-data-automation-runtime>=13.3.0, <13.4.0",
            "types-aiobotocore-bedrock-runtime>=13.3.0, <13.4.0",
            "types-aiobotocore-billing>=13.3.0, <13.4.0",
            "types-aiobotocore-billingconductor>=13.3.0, <13.4.0",
            "types-aiobotocore-braket>=13.3.0, <13.4.0",
            "types-aiobotocore-budgets>=13.3.0, <13.4.0",
            "types-aiobotocore-ce>=13.3.0, <13.4.0",
            "types-aiobotocore-chatbot>=13.3.0, <13.4.0",
            "types-aiobotocore-chime>=13.3.0, <13.4.0",
            "types-aiobotocore-chime-sdk-identity>=13.3.0, <13.4.0",
            "types-aiobotocore-chime-sdk-media-pipelines>=13.3.0, <13.4.0",
            "types-aiobotocore-chime-sdk-meetings>=13.3.0, <13.4.0",
            "types-aiobotocore-chime-sdk-messaging>=13.3.0, <13.4.0",
            "types-aiobotocore-chime-sdk-voice>=13.3.0, <13.4.0",
            "types-aiobotocore-cleanrooms>=13.3.0, <13.4.0",
            "types-aiobotocore-cleanroomsml>=13.3.0, <13.4.0",
            "types-aiobotocore-cloud9>=13.3.0, <13.4.0",
            "types-aiobotocore-cloudcontrol>=13.3.0, <13.4.0",
            "types-aiobotocore-clouddirectory>=13.3.0, <13.4.0",
            "types-aiobotocore-cloudformation>=13.3.0, <13.4.0",
            "types-aiobotocore-cloudfront>=13.3.0, <13.4.0",
            "types-aiobotocore-cloudfront-keyvaluestore>=13.3.0, <13.4.0",
            "types-aiobotocore-cloudhsm>=13.3.0, <13.4.0",
            "types-aiobotocore-cloudhsmv2>=13.3.0, <13.4.0",
            "types-aiobotocore-cloudsearch>=13.3.0, <13.4.0",
            "types-aiobotocore-cloudsearchdomain>=13.3.0, <13.4.0",
            "types-aiobotocore-cloudtrail>=13.3.0, <13.4.0",
            "types-aiobotocore-cloudtrail-data>=13.3.0, <13.4.0",
            "types-aiobotocore-cloudwatch>=13.3.0, <13.4.0",
            "types-aiobotocore-codeartifact>=13.3.0, <13.4.0",
            "types-aiobotocore-codebuild>=13.3.0, <13.4.0",
            "types-aiobotocore-codecatalyst>=13.3.0, <13.4.0",
            "types-aiobotocore-codecommit>=13.3.0, <13.4.0",
            "types-aiobotocore-codeconnections>=13.3.0, <13.4.0",
            "types-aiobotocore-codedeploy>=13.3.0, <13.4.0",
            "types-aiobotocore-codeguru-reviewer>=13.3.0, <13.4.0",
            "types-aiobotocore-codeguru-security>=13.3.0, <13.4.0",
            "types-aiobotocore-codeguruprofiler>=13.3.0, <13.4.0",
            "types-aiobotocore-codepipeline>=13.3.0, <13.4.0",
            "types-aiobotocore-codestar-connections>=13.3.0, <13.4.0",
            "types-aiobotocore-codestar-notifications>=13.3.0, <13.4.0",
            "types-aiobotocore-cognito-identity>=13.3.0, <13.4.0",
            "types-aiobotocore-cognito-idp>=13.3.0, <13.4.0",
            "types-aiobotocore-cognito-sync>=13.3.0, <13.4.0",
            "types-aiobotocore-comprehend>=13.3.0, <13.4.0",
            "types-aiobotocore-comprehendmedical>=13.3.0, <13.4.0",
            "types-aiobotocore-compute-optimizer>=13.3.0, <13.4.0",
            "types-aiobotocore-config>=13.3.0, <13.4.0",
            "types-aiobotocore-connect>=13.3.0, <13.4.0",
            "types-aiobotocore-connect-contact-lens>=13.3.0, <13.4.0",
            "types-aiobotocore-connectcampaigns>=13.3.0, <13.4.0",
            "types-aiobotocore-connectcampaignsv2>=13.3.0, <13.4.0",
            "types-aiobotocore-connectcases>=13.3.0, <13.4.0",
            "types-aiobotocore-connectparticipant>=13.3.0, <13.4.0",
            "types-aiobotocore-controlcatalog>=13.3.0, <13.4.0",
            "types-aiobotocore-controltower>=13.3.0, <13.4.0",
            "types-aiobotocore-cost-optimization-hub>=13.3.0, <13.4.0",
            "types-aiobotocore-cur>=13.3.0, <13.4.0",
            "types-aiobotocore-customer-profiles>=13.3.0, <13.4.0",
            "types-aiobotocore-databrew>=13.3.0, <13.4.0",
            "types-aiobotocore-dataexchange>=13.3.0, <13.4.0",
            "types-aiobotocore-datapipeline>=13.3.0, <13.4.0",
            "types-aiobotocore-datasync>=13.3.0, <13.4.0",
            "types-aiobotocore-datazone>=13.3.0, <13.4.0",
            "types-aiobotocore-dax>=13.3.0, <13.4.0",
            "types-aiobotocore-deadline>=13.3.0, <13.4.0",
            "types-aiobotocore-detective>=13.3.0, <13.4.0",
            "types-aiobotocore-devicefarm>=13.3.0, <13.4.0",
            "types-aiobotocore-devops-guru>=13.3.0, <13.4.0",
            "types-aiobotocore-directconnect>=13.3.0, <13.4.0",
            "types-aiobotocore-discovery>=13.3.0, <13.4.0",
            "types-aiobotocore-dlm>=13.3.0, <13.4.0",
            "types-aiobotocore-dms>=13.3.0, <13.4.0",
            "types-aiobotocore-docdb>=13.3.0, <13.4.0",
            "types-aiobotocore-docdb-elastic>=13.3.0, <13.4.0",
            "types-aiobotocore-drs>=13.3.0, <13.4.0",
            "types-aiobotocore-ds>=13.3.0, <13.4.0",
            "types-aiobotocore-ds-data>=13.3.0, <13.4.0",
            "types-aiobotocore-dsql>=13.3.0, <13.4.0",
            "types-aiobotocore-dynamodb>=13.3.0, <13.4.0",
            "types-aiobotocore-dynamodbstreams>=13.3.0, <13.4.0",
            "types-aiobotocore-ebs>=13.3.0, <13.4.0",
            "types-aiobotocore-ec2>=13.3.0, <13.4.0",
            "types-aiobotocore-ec2-instance-connect>=13.3.0, <13.4.0",
            "types-aiobotocore-ecr>=13.3.0, <13.4.0",
            "types-aiobotocore-ecr-public>=13.3.0, <13.4.0",
            "types-aiobotocore-ecs>=13.3.0, <13.4.0",
            "types-aiobotocore-efs>=13.3.0, <13.4.0",
            "types-aiobotocore-eks>=13.3.0, <13.4.0",
            "types-aiobotocore-eks-auth>=13.3.0, <13.4.0",
            "types-aiobotocore-elastic-inference>=13.3.0, <13.4.0",
            "types-aiobotocore-elasticache>=13.3.0, <13.4.0",
            "types-aiobotocore-elasticbeanstalk>=13.3.0, <13.4.0",
            "types-aiobotocore-elastictranscoder>=13.3.0, <13.4.0",
            "types-aiobotocore-elb>=13.3.0, <13.4.0",
            "types-aiobotocore-elbv2>=13.3.0, <13.4.0",
            "types-aiobotocore-emr>=13.3.0, <13.4.0",
            "types-aiobotocore-emr-containers>=13.3.0, <13.4.0",
            "types-aiobotocore-emr-serverless>=13.3.0, <13.4.0",
            "types-aiobotocore-entityresolution>=13.3.0, <13.4.0",
            "types-aiobotocore-es>=13.3.0, <13.4.0",
            "types-aiobotocore-events>=13.3.0, <13.4.0",
            "types-aiobotocore-evidently>=13.3.0, <13.4.0",
            "types-aiobotocore-finspace>=13.3.0, <13.4.0",
            "types-aiobotocore-finspace-data>=13.3.0, <13.4.0",
            "types-aiobotocore-firehose>=13.3.0, <13.4.0",
            "types-aiobotocore-fis>=13.3.0, <13.4.0",
            "types-aiobotocore-fms>=13.3.0, <13.4.0",
            "types-aiobotocore-forecast>=13.3.0, <13.4.0",
            "types-aiobotocore-forecastquery>=13.3.0, <13.4.0",
            "types-aiobotocore-frauddetector>=13.3.0, <13.4.0",
            "types-aiobotocore-freetier>=13.3.0, <13.4.0",
            "types-aiobotocore-fsx>=13.3.0, <13.4.0",
            "types-aiobotocore-gamelift>=13.3.0, <13.4.0",
            "types-aiobotocore-geo-maps>=13.3.0, <13.4.0",
            "types-aiobotocore-geo-places>=13.3.0, <13.4.0",
            "types-aiobotocore-geo-routes>=13.3.0, <13.4.0",
            "types-aiobotocore-glacier>=13.3.0, <13.4.0",
            "types-aiobotocore-globalaccelerator>=13.3.0, <13.4.0",
            "types-aiobotocore-glue>=13.3.0, <13.4.0",
            "types-aiobotocore-grafana>=13.3.0, <13.4.0",
            "types-aiobotocore-greengrass>=13.3.0, <13.4.0",
            "types-aiobotocore-greengrassv2>=13.3.0, <13.4.0",
            "types-aiobotocore-groundstation>=13.3.0, <13.4.0",
            "types-aiobotocore-guardduty>=13.3.0, <13.4.0",
            "types-aiobotocore-health>=13.3.0, <13.4.0",
            "types-aiobotocore-healthlake>=13.3.0, <13.4.0",
            "types-aiobotocore-iam>=13.3.0, <13.4.0",
            "types-aiobotocore-identitystore>=13.3.0, <13.4.0",
            "types-aiobotocore-imagebuilder>=13.3.0, <13.4.0",
            "types-aiobotocore-importexport>=13.3.0, <13.4.0",
            "types-aiobotocore-inspector>=13.3.0, <13.4.0",
            "types-aiobotocore-inspector-scan>=13.3.0, <13.4.0",
            "types-aiobotocore-inspector2>=13.3.0, <13.4.0",
            "types-aiobotocore-internetmonitor>=13.3.0, <13.4.0",
            "types-aiobotocore-invoicing>=13.3.0, <13.4.0",
            "types-aiobotocore-iot>=13.3.0, <13.4.0",
            "types-aiobotocore-iot-data>=13.3.0, <13.4.0",
            "types-aiobotocore-iot-jobs-data>=13.3.0, <13.4.0",
            "types-aiobotocore-iot1click-devices>=13.3.0, <13.4.0",
            "types-aiobotocore-iot1click-projects>=13.3.0, <13.4.0",
            "types-aiobotocore-iotanalytics>=13.3.0, <13.4.0",
            "types-aiobotocore-iotdeviceadvisor>=13.3.0, <13.4.0",
            "types-aiobotocore-iotevents>=13.3.0, <13.4.0",
            "types-aiobotocore-iotevents-data>=13.3.0, <13.4.0",
            "types-aiobotocore-iotfleethub>=13.3.0, <13.4.0",
            "types-aiobotocore-iotfleetwise>=13.3.0, <13.4.0",
            "types-aiobotocore-iotsecuretunneling>=13.3.0, <13.4.0",
            "types-aiobotocore-iotsitewise>=13.3.0, <13.4.0",
            "types-aiobotocore-iotthingsgraph>=13.3.0, <13.4.0",
            "types-aiobotocore-iottwinmaker>=13.3.0, <13.4.0",
            "types-aiobotocore-iotwireless>=13.3.0, <13.4.0",
            "types-aiobotocore-ivs>=13.3.0, <13.4.0",
            "types-aiobotocore-ivs-realtime>=13.3.0, <13.4.0",
            "types-aiobotocore-ivschat>=13.3.0, <13.4.0",
            "types-aiobotocore-kafka>=13.3.0, <13.4.0",
            "types-aiobotocore-kafkaconnect>=13.3.0, <13.4.0",
            "types-aiobotocore-kendra>=13.3.0, <13.4.0",
            "types-aiobotocore-kendra-ranking>=13.3.0, <13.4.0",
            "types-aiobotocore-keyspaces>=13.3.0, <13.4.0",
            "types-aiobotocore-kinesis>=13.3.0, <13.4.0",
            "types-aiobotocore-kinesis-video-archived-media>=13.3.0, <13.4.0",
            "types-aiobotocore-kinesis-video-media>=13.3.0, <13.4.0",
            "types-aiobotocore-kinesis-video-signaling>=13.3.0, <13.4.0",
            "types-aiobotocore-kinesis-video-webrtc-storage>=13.3.0, <13.4.0",
            "types-aiobotocore-kinesisanalytics>=13.3.0, <13.4.0",
            "types-aiobotocore-kinesisanalyticsv2>=13.3.0, <13.4.0",
            "types-aiobotocore-kinesisvideo>=13.3.0, <13.4.0",
            "types-aiobotocore-kms>=13.3.0, <13.4.0",
            "types-aiobotocore-lakeformation>=13.3.0, <13.4.0",
            "types-aiobotocore-lambda>=13.3.0, <13.4.0",
            "types-aiobotocore-launch-wizard>=13.3.0, <13.4.0",
            "types-aiobotocore-lex-models>=13.3.0, <13.4.0",
            "types-aiobotocore-lex-runtime>=13.3.0, <13.4.0",
            "types-aiobotocore-lexv2-models>=13.3.0, <13.4.0",
            "types-aiobotocore-lexv2-runtime>=13.3.0, <13.4.0",
            "types-aiobotocore-license-manager>=13.3.0, <13.4.0",
            "types-aiobotocore-license-manager-linux-subscriptions>=13.3.0, <13.4.0",
            "types-aiobotocore-license-manager-user-subscriptions>=13.3.0, <13.4.0",
            "types-aiobotocore-lightsail>=13.3.0, <13.4.0",
            "types-aiobotocore-location>=13.3.0, <13.4.0",
            "types-aiobotocore-logs>=13.3.0, <13.4.0",
            "types-aiobotocore-lookoutequipment>=13.3.0, <13.4.0",
            "types-aiobotocore-lookoutmetrics>=13.3.0, <13.4.0",
            "types-aiobotocore-lookoutvision>=13.3.0, <13.4.0",
            "types-aiobotocore-m2>=13.3.0, <13.4.0",
            "types-aiobotocore-machinelearning>=13.3.0, <13.4.0",
            "types-aiobotocore-macie2>=13.3.0, <13.4.0",
            "types-aiobotocore-mailmanager>=13.3.0, <13.4.0",
            "types-aiobotocore-managedblockchain>=13.3.0, <13.4.0",
            "types-aiobotocore-managedblockchain-query>=13.3.0, <13.4.0",
            "types-aiobotocore-marketplace-agreement>=13.3.0, <13.4.0",
            "types-aiobotocore-marketplace-catalog>=13.3.0, <13.4.0",
            "types-aiobotocore-marketplace-deployment>=13.3.0, <13.4.0",
            "types-aiobotocore-marketplace-entitlement>=13.3.0, <13.4.0",
            "types-aiobotocore-marketplace-reporting>=13.3.0, <13.4.0",
            "types-aiobotocore-marketplacecommerceanalytics>=13.3.0, <13.4.0",
            "types-aiobotocore-mediaconnect>=13.3.0, <13.4.0",
            "types-aiobotocore-mediaconvert>=13.3.0, <13.4.0",
            "types-aiobotocore-medialive>=13.3.0, <13.4.0",
            "types-aiobotocore-mediapackage>=13.3.0, <13.4.0",
            "types-aiobotocore-mediapackage-vod>=13.3.0, <13.4.0",
            "types-aiobotocore-mediapackagev2>=13.3.0, <13.4.0",
            "types-aiobotocore-mediastore>=13.3.0, <13.4.0",
            "types-aiobotocore-mediastore-data>=13.3.0, <13.4.0",
            "types-aiobotocore-mediatailor>=13.3.0, <13.4.0",
            "types-aiobotocore-medical-imaging>=13.3.0, <13.4.0",
            "types-aiobotocore-memorydb>=13.3.0, <13.4.0",
            "types-aiobotocore-meteringmarketplace>=13.3.0, <13.4.0",
            "types-aiobotocore-mgh>=13.3.0, <13.4.0",
            "types-aiobotocore-mgn>=13.3.0, <13.4.0",
            "types-aiobotocore-migration-hub-refactor-spaces>=13.3.0, <13.4.0",
            "types-aiobotocore-migrationhub-config>=13.3.0, <13.4.0",
            "types-aiobotocore-migrationhuborchestrator>=13.3.0, <13.4.0",
            "types-aiobotocore-migrationhubstrategy>=13.3.0, <13.4.0",
            "types-aiobotocore-mq>=13.3.0, <13.4.0",
            "types-aiobotocore-mturk>=13.3.0, <13.4.0",
            "types-aiobotocore-mwaa>=13.3.0, <13.4.0",
            "types-aiobotocore-neptune>=13.3.0, <13.4.0",
            "types-aiobotocore-neptune-graph>=13.3.0, <13.4.0",
            "types-aiobotocore-neptunedata>=13.3.0, <13.4.0",
            "types-aiobotocore-network-firewall>=13.3.0, <13.4.0",
            "types-aiobotocore-networkflowmonitor>=13.3.0, <13.4.0",
            "types-aiobotocore-networkmanager>=13.3.0, <13.4.0",
            "types-aiobotocore-networkmonitor>=13.3.0, <13.4.0",
            "types-aiobotocore-notifications>=13.3.0, <13.4.0",
            "types-aiobotocore-notificationscontacts>=13.3.0, <13.4.0",
            "types-aiobotocore-oam>=13.3.0, <13.4.0",
            "types-aiobotocore-observabilityadmin>=13.3.0, <13.4.0",
            "types-aiobotocore-omics>=13.3.0, <13.4.0",
            "types-aiobotocore-opensearch>=13.3.0, <13.4.0",
            "types-aiobotocore-opensearchserverless>=13.3.0, <13.4.0",
            "types-aiobotocore-opsworks>=13.3.0, <13.4.0",
            "types-aiobotocore-opsworkscm>=13.3.0, <13.4.0",
            "types-aiobotocore-organizations>=13.3.0, <13.4.0",
            "types-aiobotocore-osis>=13.3.0, <13.4.0",
            "types-aiobotocore-outposts>=13.3.0, <13.4.0",
            "types-aiobotocore-panorama>=13.3.0, <13.4.0",
            "types-aiobotocore-partnercentral-selling>=13.3.0, <13.4.0",
            "types-aiobotocore-payment-cryptography>=13.3.0, <13.4.0",
            "types-aiobotocore-payment-cryptography-data>=13.3.0, <13.4.0",
            "types-aiobotocore-pca-connector-ad>=13.3.0, <13.4.0",
            "types-aiobotocore-pca-connector-scep>=13.3.0, <13.4.0",
            "types-aiobotocore-pcs>=13.3.0, <13.4.0",
            "types-aiobotocore-personalize>=13.3.0, <13.4.0",
            "types-aiobotocore-personalize-events>=13.3.0, <13.4.0",
            "types-aiobotocore-personalize-runtime>=13.3.0, <13.4.0",
            "types-aiobotocore-pi>=13.3.0, <13.4.0",
            "types-aiobotocore-pinpoint>=13.3.0, <13.4.0",
            "types-aiobotocore-pinpoint-email>=13.3.0, <13.4.0",
            "types-aiobotocore-pinpoint-sms-voice>=13.3.0, <13.4.0",
            "types-aiobotocore-pinpoint-sms-voice-v2>=13.3.0, <13.4.0",
            "types-aiobotocore-pipes>=13.3.0, <13.4.0",
            "types-aiobotocore-polly>=13.3.0, <13.4.0",
            "types-aiobotocore-pricing>=13.3.0, <13.4.0",
            "types-aiobotocore-privatenetworks>=13.3.0, <13.4.0",
            "types-aiobotocore-proton>=13.3.0, <13.4.0",
            "types-aiobotocore-qapps>=13.3.0, <13.4.0",
            "types-aiobotocore-qbusiness>=13.3.0, <13.4.0",
            "types-aiobotocore-qconnect>=13.3.0, <13.4.0",
            "types-aiobotocore-qldb>=13.3.0, <13.4.0",
            "types-aiobotocore-qldb-session>=13.3.0, <13.4.0",
            "types-aiobotocore-quicksight>=13.3.0, <13.4.0",
            "types-aiobotocore-ram>=13.3.0, <13.4.0",
            "types-aiobotocore-rbin>=13.3.0, <13.4.0",
            "types-aiobotocore-rds>=13.3.0, <13.4.0",
            "types-aiobotocore-rds-data>=13.3.0, <13.4.0",
            "types-aiobotocore-redshift>=13.3.0, <13.4.0",
            "types-aiobotocore-redshift-data>=13.3.0, <13.4.0",
            "types-aiobotocore-redshift-serverless>=13.3.0, <13.4.0",
            "types-aiobotocore-rekognition>=13.3.0, <13.4.0",
            "types-aiobotocore-repostspace>=13.3.0, <13.4.0",
            "types-aiobotocore-resiliencehub>=13.3.0, <13.4.0",
            "types-aiobotocore-resource-explorer-2>=13.3.0, <13.4.0",
            "types-aiobotocore-resource-groups>=13.3.0, <13.4.0",
            "types-aiobotocore-resourcegroupstaggingapi>=13.3.0, <13.4.0",
            "types-aiobotocore-robomaker>=13.3.0, <13.4.0",
            "types-aiobotocore-rolesanywhere>=13.3.0, <13.4.0",
            "types-aiobotocore-route53>=13.3.0, <13.4.0",
            "types-aiobotocore-route53-recovery-cluster>=13.3.0, <13.4.0",
            "types-aiobotocore-route53-recovery-control-config>=13.3.0, <13.4.0",
            "types-aiobotocore-route53-recovery-readiness>=13.3.0, <13.4.0",
            "types-aiobotocore-route53domains>=13.3.0, <13.4.0",
            "types-aiobotocore-route53profiles>=13.3.0, <13.4.0",
            "types-aiobotocore-route53resolver>=13.3.0, <13.4.0",
            "types-aiobotocore-rum>=13.3.0, <13.4.0",
            "types-aiobotocore-s3>=13.3.0, <13.4.0",
            "types-aiobotocore-s3control>=13.3.0, <13.4.0",
            "types-aiobotocore-s3outposts>=13.3.0, <13.4.0",
            "types-aiobotocore-s3tables>=13.3.0, <13.4.0",
            "types-aiobotocore-sagemaker>=13.3.0, <13.4.0",
            "types-aiobotocore-sagemaker-a2i-runtime>=13.3.0, <13.4.0",
            "types-aiobotocore-sagemaker-edge>=13.3.0, <13.4.0",
            "types-aiobotocore-sagemaker-featurestore-runtime>=13.3.0, <13.4.0",
            "types-aiobotocore-sagemaker-geospatial>=13.3.0, <13.4.0",
            "types-aiobotocore-sagemaker-metrics>=13.3.0, <13.4.0",
            "types-aiobotocore-sagemaker-runtime>=13.3.0, <13.4.0",
            "types-aiobotocore-savingsplans>=13.3.0, <13.4.0",
            "types-aiobotocore-scheduler>=13.3.0, <13.4.0",
            "types-aiobotocore-schemas>=13.3.0, <13.4.0",
            "types-aiobotocore-sdb>=13.3.0, <13.4.0",
            "types-aiobotocore-secretsmanager>=13.3.0, <13.4.0",
            "types-aiobotocore-security-ir>=13.3.0, <13.4.0",
            "types-aiobotocore-securityhub>=13.3.0, <13.4.0",
            "types-aiobotocore-securitylake>=13.3.0, <13.4.0",
            "types-aiobotocore-serverlessrepo>=13.3.0, <13.4.0",
            "types-aiobotocore-service-quotas>=13.3.0, <13.4.0",
            "types-aiobotocore-servicecatalog>=13.3.0, <13.4.0",
            "types-aiobotocore-servicecatalog-appregistry>=13.3.0, <13.4.0",
            "types-aiobotocore-servicediscovery>=13.3.0, <13.4.0",
            "types-aiobotocore-ses>=13.3.0, <13.4.0",
            "types-aiobotocore-sesv2>=13.3.0, <13.4.0",
            "types-aiobotocore-shield>=13.3.0, <13.4.0",
            "types-aiobotocore-signer>=13.3.0, <13.4.0",
            "types-aiobotocore-simspaceweaver>=13.3.0, <13.4.0",
            "types-aiobotocore-sms>=13.3.0, <13.4.0",
            "types-aiobotocore-sms-voice>=13.3.0, <13.4.0",
            "types-aiobotocore-snow-device-management>=13.3.0, <13.4.0",
            "types-aiobotocore-snowball>=13.3.0, <13.4.0",
            "types-aiobotocore-sns>=13.3.0, <13.4.0",
            "types-aiobotocore-socialmessaging>=13.3.0, <13.4.0",
            "types-aiobotocore-sqs>=13.3.0, <13.4.0",
            "types-aiobotocore-ssm>=13.3.0, <13.4.0",
            "types-aiobotocore-ssm-contacts>=13.3.0, <13.4.0",
            "types-aiobotocore-ssm-incidents>=13.3.0, <13.4.0",
            "types-aiobotocore-ssm-quicksetup>=13.3.0, <13.4.0",
            "types-aiobotocore-ssm-sap>=13.3.0, <13.4.0",
            "types-aiobotocore-sso>=13.3.0, <13.4.0",
            "types-aiobotocore-sso-admin>=13.3.0, <13.4.0",
            "types-aiobotocore-sso-oidc>=13.3.0, <13.4.0",
            "types-aiobotocore-stepfunctions>=13.3.0, <13.4.0",
            "types-aiobotocore-storagegateway>=13.3.0, <13.4.0",
            "types-aiobotocore-sts>=13.3.0, <13.4.0",
            "types-aiobotocore-supplychain>=13.3.0, <13.4.0",
            "types-aiobotocore-support>=13.3.0, <13.4.0",
            "types-aiobotocore-support-app>=13.3.0, <13.4.0",
            "types-aiobotocore-swf>=13.3.0, <13.4.0",
            "types-aiobotocore-synthetics>=13.3.0, <13.4.0",
            "types-aiobotocore-taxsettings>=13.3.0, <13.4.0",
            "types-aiobotocore-textract>=13.3.0, <13.4.0",
            "types-aiobotocore-timestream-influxdb>=13.3.0, <13.4.0",
            "types-aiobotocore-timestream-query>=13.3.0, <13.4.0",
            "types-aiobotocore-timestream-write>=13.3.0, <13.4.0",
            "types-aiobotocore-tnb>=13.3.0, <13.4.0",
            "types-aiobotocore-transcribe>=13.3.0, <13.4.0",
            "types-aiobotocore-transfer>=13.3.0, <13.4.0",
            "types-aiobotocore-translate>=13.3.0, <13.4.0",
            "types-aiobotocore-trustedadvisor>=13.3.0, <13.4.0",
            "types-aiobotocore-verifiedpermissions>=13.3.0, <13.4.0",
            "types-aiobotocore-voice-id>=13.3.0, <13.4.0",
            "types-aiobotocore-vpc-lattice>=13.3.0, <13.4.0",
            "types-aiobotocore-waf>=13.3.0, <13.4.0",
            "types-aiobotocore-waf-regional>=13.3.0, <13.4.0",
            "types-aiobotocore-wafv2>=13.3.0, <13.4.0",
            "types-aiobotocore-wellarchitected>=13.3.0, <13.4.0",
            "types-aiobotocore-wisdom>=13.3.0, <13.4.0",
            "types-aiobotocore-workdocs>=13.3.0, <13.4.0",
            "types-aiobotocore-workmail>=13.3.0, <13.4.0",
            "types-aiobotocore-workmailmessageflow>=13.3.0, <13.4.0",
            "types-aiobotocore-workspaces>=13.3.0, <13.4.0",
            "types-aiobotocore-workspaces-thin-client>=13.3.0, <13.4.0",
            "types-aiobotocore-workspaces-web>=13.3.0, <13.4.0",
            "types-aiobotocore-xray>=13.3.0, <13.4.0",
        ],
        "essential": [
            "types-aiobotocore-cloudformation>=13.3.0, <13.4.0",
            "types-aiobotocore-dynamodb>=13.3.0, <13.4.0",
            "types-aiobotocore-ec2>=13.3.0, <13.4.0",
            "types-aiobotocore-lambda>=13.3.0, <13.4.0",
            "types-aiobotocore-rds>=13.3.0, <13.4.0",
            "types-aiobotocore-s3>=13.3.0, <13.4.0",
            "types-aiobotocore-sqs>=13.3.0, <13.4.0",
        ],
        "accessanalyzer": ["types-aiobotocore-accessanalyzer>=13.3.0, <13.4.0"],
        "account": ["types-aiobotocore-account>=13.3.0, <13.4.0"],
        "acm": ["types-aiobotocore-acm>=13.3.0, <13.4.0"],
        "acm-pca": ["types-aiobotocore-acm-pca>=13.3.0, <13.4.0"],
        "amp": ["types-aiobotocore-amp>=13.3.0, <13.4.0"],
        "amplify": ["types-aiobotocore-amplify>=13.3.0, <13.4.0"],
        "amplifybackend": ["types-aiobotocore-amplifybackend>=13.3.0, <13.4.0"],
        "amplifyuibuilder": ["types-aiobotocore-amplifyuibuilder>=13.3.0, <13.4.0"],
        "apigateway": ["types-aiobotocore-apigateway>=13.3.0, <13.4.0"],
        "apigatewaymanagementapi": ["types-aiobotocore-apigatewaymanagementapi>=13.3.0, <13.4.0"],
        "apigatewayv2": ["types-aiobotocore-apigatewayv2>=13.3.0, <13.4.0"],
        "appconfig": ["types-aiobotocore-appconfig>=13.3.0, <13.4.0"],
        "appconfigdata": ["types-aiobotocore-appconfigdata>=13.3.0, <13.4.0"],
        "appfabric": ["types-aiobotocore-appfabric>=13.3.0, <13.4.0"],
        "appflow": ["types-aiobotocore-appflow>=13.3.0, <13.4.0"],
        "appintegrations": ["types-aiobotocore-appintegrations>=13.3.0, <13.4.0"],
        "application-autoscaling": ["types-aiobotocore-application-autoscaling>=13.3.0, <13.4.0"],
        "application-insights": ["types-aiobotocore-application-insights>=13.3.0, <13.4.0"],
        "application-signals": ["types-aiobotocore-application-signals>=13.3.0, <13.4.0"],
        "applicationcostprofiler": ["types-aiobotocore-applicationcostprofiler>=13.3.0, <13.4.0"],
        "appmesh": ["types-aiobotocore-appmesh>=13.3.0, <13.4.0"],
        "apprunner": ["types-aiobotocore-apprunner>=13.3.0, <13.4.0"],
        "appstream": ["types-aiobotocore-appstream>=13.3.0, <13.4.0"],
        "appsync": ["types-aiobotocore-appsync>=13.3.0, <13.4.0"],
        "apptest": ["types-aiobotocore-apptest>=13.3.0, <13.4.0"],
        "arc-zonal-shift": ["types-aiobotocore-arc-zonal-shift>=13.3.0, <13.4.0"],
        "artifact": ["types-aiobotocore-artifact>=13.3.0, <13.4.0"],
        "athena": ["types-aiobotocore-athena>=13.3.0, <13.4.0"],
        "auditmanager": ["types-aiobotocore-auditmanager>=13.3.0, <13.4.0"],
        "autoscaling": ["types-aiobotocore-autoscaling>=13.3.0, <13.4.0"],
        "autoscaling-plans": ["types-aiobotocore-autoscaling-plans>=13.3.0, <13.4.0"],
        "b2bi": ["types-aiobotocore-b2bi>=13.3.0, <13.4.0"],
        "backup": ["types-aiobotocore-backup>=13.3.0, <13.4.0"],
        "backup-gateway": ["types-aiobotocore-backup-gateway>=13.3.0, <13.4.0"],
        "batch": ["types-aiobotocore-batch>=13.3.0, <13.4.0"],
        "bcm-data-exports": ["types-aiobotocore-bcm-data-exports>=13.3.0, <13.4.0"],
        "bcm-pricing-calculator": ["types-aiobotocore-bcm-pricing-calculator>=13.3.0, <13.4.0"],
        "bedrock": ["types-aiobotocore-bedrock>=13.3.0, <13.4.0"],
        "bedrock-agent": ["types-aiobotocore-bedrock-agent>=13.3.0, <13.4.0"],
        "bedrock-agent-runtime": ["types-aiobotocore-bedrock-agent-runtime>=13.3.0, <13.4.0"],
        "bedrock-data-automation": ["types-aiobotocore-bedrock-data-automation>=13.3.0, <13.4.0"],
        "bedrock-data-automation-runtime": [
            "types-aiobotocore-bedrock-data-automation-runtime>=13.3.0, <13.4.0"
        ],
        "bedrock-runtime": ["types-aiobotocore-bedrock-runtime>=13.3.0, <13.4.0"],
        "billing": ["types-aiobotocore-billing>=13.3.0, <13.4.0"],
        "billingconductor": ["types-aiobotocore-billingconductor>=13.3.0, <13.4.0"],
        "braket": ["types-aiobotocore-braket>=13.3.0, <13.4.0"],
        "budgets": ["types-aiobotocore-budgets>=13.3.0, <13.4.0"],
        "ce": ["types-aiobotocore-ce>=13.3.0, <13.4.0"],
        "chatbot": ["types-aiobotocore-chatbot>=13.3.0, <13.4.0"],
        "chime": ["types-aiobotocore-chime>=13.3.0, <13.4.0"],
        "chime-sdk-identity": ["types-aiobotocore-chime-sdk-identity>=13.3.0, <13.4.0"],
        "chime-sdk-media-pipelines": [
            "types-aiobotocore-chime-sdk-media-pipelines>=13.3.0, <13.4.0"
        ],
        "chime-sdk-meetings": ["types-aiobotocore-chime-sdk-meetings>=13.3.0, <13.4.0"],
        "chime-sdk-messaging": ["types-aiobotocore-chime-sdk-messaging>=13.3.0, <13.4.0"],
        "chime-sdk-voice": ["types-aiobotocore-chime-sdk-voice>=13.3.0, <13.4.0"],
        "cleanrooms": ["types-aiobotocore-cleanrooms>=13.3.0, <13.4.0"],
        "cleanroomsml": ["types-aiobotocore-cleanroomsml>=13.3.0, <13.4.0"],
        "cloud9": ["types-aiobotocore-cloud9>=13.3.0, <13.4.0"],
        "cloudcontrol": ["types-aiobotocore-cloudcontrol>=13.3.0, <13.4.0"],
        "clouddirectory": ["types-aiobotocore-clouddirectory>=13.3.0, <13.4.0"],
        "cloudformation": ["types-aiobotocore-cloudformation>=13.3.0, <13.4.0"],
        "cloudfront": ["types-aiobotocore-cloudfront>=13.3.0, <13.4.0"],
        "cloudfront-keyvaluestore": ["types-aiobotocore-cloudfront-keyvaluestore>=13.3.0, <13.4.0"],
        "cloudhsm": ["types-aiobotocore-cloudhsm>=13.3.0, <13.4.0"],
        "cloudhsmv2": ["types-aiobotocore-cloudhsmv2>=13.3.0, <13.4.0"],
        "cloudsearch": ["types-aiobotocore-cloudsearch>=13.3.0, <13.4.0"],
        "cloudsearchdomain": ["types-aiobotocore-cloudsearchdomain>=13.3.0, <13.4.0"],
        "cloudtrail": ["types-aiobotocore-cloudtrail>=13.3.0, <13.4.0"],
        "cloudtrail-data": ["types-aiobotocore-cloudtrail-data>=13.3.0, <13.4.0"],
        "cloudwatch": ["types-aiobotocore-cloudwatch>=13.3.0, <13.4.0"],
        "codeartifact": ["types-aiobotocore-codeartifact>=13.3.0, <13.4.0"],
        "codebuild": ["types-aiobotocore-codebuild>=13.3.0, <13.4.0"],
        "codecatalyst": ["types-aiobotocore-codecatalyst>=13.3.0, <13.4.0"],
        "codecommit": ["types-aiobotocore-codecommit>=13.3.0, <13.4.0"],
        "codeconnections": ["types-aiobotocore-codeconnections>=13.3.0, <13.4.0"],
        "codedeploy": ["types-aiobotocore-codedeploy>=13.3.0, <13.4.0"],
        "codeguru-reviewer": ["types-aiobotocore-codeguru-reviewer>=13.3.0, <13.4.0"],
        "codeguru-security": ["types-aiobotocore-codeguru-security>=13.3.0, <13.4.0"],
        "codeguruprofiler": ["types-aiobotocore-codeguruprofiler>=13.3.0, <13.4.0"],
        "codepipeline": ["types-aiobotocore-codepipeline>=13.3.0, <13.4.0"],
        "codestar-connections": ["types-aiobotocore-codestar-connections>=13.3.0, <13.4.0"],
        "codestar-notifications": ["types-aiobotocore-codestar-notifications>=13.3.0, <13.4.0"],
        "cognito-identity": ["types-aiobotocore-cognito-identity>=13.3.0, <13.4.0"],
        "cognito-idp": ["types-aiobotocore-cognito-idp>=13.3.0, <13.4.0"],
        "cognito-sync": ["types-aiobotocore-cognito-sync>=13.3.0, <13.4.0"],
        "comprehend": ["types-aiobotocore-comprehend>=13.3.0, <13.4.0"],
        "comprehendmedical": ["types-aiobotocore-comprehendmedical>=13.3.0, <13.4.0"],
        "compute-optimizer": ["types-aiobotocore-compute-optimizer>=13.3.0, <13.4.0"],
        "config": ["types-aiobotocore-config>=13.3.0, <13.4.0"],
        "connect": ["types-aiobotocore-connect>=13.3.0, <13.4.0"],
        "connect-contact-lens": ["types-aiobotocore-connect-contact-lens>=13.3.0, <13.4.0"],
        "connectcampaigns": ["types-aiobotocore-connectcampaigns>=13.3.0, <13.4.0"],
        "connectcampaignsv2": ["types-aiobotocore-connectcampaignsv2>=13.3.0, <13.4.0"],
        "connectcases": ["types-aiobotocore-connectcases>=13.3.0, <13.4.0"],
        "connectparticipant": ["types-aiobotocore-connectparticipant>=13.3.0, <13.4.0"],
        "controlcatalog": ["types-aiobotocore-controlcatalog>=13.3.0, <13.4.0"],
        "controltower": ["types-aiobotocore-controltower>=13.3.0, <13.4.0"],
        "cost-optimization-hub": ["types-aiobotocore-cost-optimization-hub>=13.3.0, <13.4.0"],
        "cur": ["types-aiobotocore-cur>=13.3.0, <13.4.0"],
        "customer-profiles": ["types-aiobotocore-customer-profiles>=13.3.0, <13.4.0"],
        "databrew": ["types-aiobotocore-databrew>=13.3.0, <13.4.0"],
        "dataexchange": ["types-aiobotocore-dataexchange>=13.3.0, <13.4.0"],
        "datapipeline": ["types-aiobotocore-datapipeline>=13.3.0, <13.4.0"],
        "datasync": ["types-aiobotocore-datasync>=13.3.0, <13.4.0"],
        "datazone": ["types-aiobotocore-datazone>=13.3.0, <13.4.0"],
        "dax": ["types-aiobotocore-dax>=13.3.0, <13.4.0"],
        "deadline": ["types-aiobotocore-deadline>=13.3.0, <13.4.0"],
        "detective": ["types-aiobotocore-detective>=13.3.0, <13.4.0"],
        "devicefarm": ["types-aiobotocore-devicefarm>=13.3.0, <13.4.0"],
        "devops-guru": ["types-aiobotocore-devops-guru>=13.3.0, <13.4.0"],
        "directconnect": ["types-aiobotocore-directconnect>=13.3.0, <13.4.0"],
        "discovery": ["types-aiobotocore-discovery>=13.3.0, <13.4.0"],
        "dlm": ["types-aiobotocore-dlm>=13.3.0, <13.4.0"],
        "dms": ["types-aiobotocore-dms>=13.3.0, <13.4.0"],
        "docdb": ["types-aiobotocore-docdb>=13.3.0, <13.4.0"],
        "docdb-elastic": ["types-aiobotocore-docdb-elastic>=13.3.0, <13.4.0"],
        "drs": ["types-aiobotocore-drs>=13.3.0, <13.4.0"],
        "ds": ["types-aiobotocore-ds>=13.3.0, <13.4.0"],
        "ds-data": ["types-aiobotocore-ds-data>=13.3.0, <13.4.0"],
        "dsql": ["types-aiobotocore-dsql>=13.3.0, <13.4.0"],
        "dynamodb": ["types-aiobotocore-dynamodb>=13.3.0, <13.4.0"],
        "dynamodbstreams": ["types-aiobotocore-dynamodbstreams>=13.3.0, <13.4.0"],
        "ebs": ["types-aiobotocore-ebs>=13.3.0, <13.4.0"],
        "ec2": ["types-aiobotocore-ec2>=13.3.0, <13.4.0"],
        "ec2-instance-connect": ["types-aiobotocore-ec2-instance-connect>=13.3.0, <13.4.0"],
        "ecr": ["types-aiobotocore-ecr>=13.3.0, <13.4.0"],
        "ecr-public": ["types-aiobotocore-ecr-public>=13.3.0, <13.4.0"],
        "ecs": ["types-aiobotocore-ecs>=13.3.0, <13.4.0"],
        "efs": ["types-aiobotocore-efs>=13.3.0, <13.4.0"],
        "eks": ["types-aiobotocore-eks>=13.3.0, <13.4.0"],
        "eks-auth": ["types-aiobotocore-eks-auth>=13.3.0, <13.4.0"],
        "elastic-inference": ["types-aiobotocore-elastic-inference>=13.3.0, <13.4.0"],
        "elasticache": ["types-aiobotocore-elasticache>=13.3.0, <13.4.0"],
        "elasticbeanstalk": ["types-aiobotocore-elasticbeanstalk>=13.3.0, <13.4.0"],
        "elastictranscoder": ["types-aiobotocore-elastictranscoder>=13.3.0, <13.4.0"],
        "elb": ["types-aiobotocore-elb>=13.3.0, <13.4.0"],
        "elbv2": ["types-aiobotocore-elbv2>=13.3.0, <13.4.0"],
        "emr": ["types-aiobotocore-emr>=13.3.0, <13.4.0"],
        "emr-containers": ["types-aiobotocore-emr-containers>=13.3.0, <13.4.0"],
        "emr-serverless": ["types-aiobotocore-emr-serverless>=13.3.0, <13.4.0"],
        "entityresolution": ["types-aiobotocore-entityresolution>=13.3.0, <13.4.0"],
        "es": ["types-aiobotocore-es>=13.3.0, <13.4.0"],
        "events": ["types-aiobotocore-events>=13.3.0, <13.4.0"],
        "evidently": ["types-aiobotocore-evidently>=13.3.0, <13.4.0"],
        "finspace": ["types-aiobotocore-finspace>=13.3.0, <13.4.0"],
        "finspace-data": ["types-aiobotocore-finspace-data>=13.3.0, <13.4.0"],
        "firehose": ["types-aiobotocore-firehose>=13.3.0, <13.4.0"],
        "fis": ["types-aiobotocore-fis>=13.3.0, <13.4.0"],
        "fms": ["types-aiobotocore-fms>=13.3.0, <13.4.0"],
        "forecast": ["types-aiobotocore-forecast>=13.3.0, <13.4.0"],
        "forecastquery": ["types-aiobotocore-forecastquery>=13.3.0, <13.4.0"],
        "frauddetector": ["types-aiobotocore-frauddetector>=13.3.0, <13.4.0"],
        "freetier": ["types-aiobotocore-freetier>=13.3.0, <13.4.0"],
        "fsx": ["types-aiobotocore-fsx>=13.3.0, <13.4.0"],
        "gamelift": ["types-aiobotocore-gamelift>=13.3.0, <13.4.0"],
        "geo-maps": ["types-aiobotocore-geo-maps>=13.3.0, <13.4.0"],
        "geo-places": ["types-aiobotocore-geo-places>=13.3.0, <13.4.0"],
        "geo-routes": ["types-aiobotocore-geo-routes>=13.3.0, <13.4.0"],
        "glacier": ["types-aiobotocore-glacier>=13.3.0, <13.4.0"],
        "globalaccelerator": ["types-aiobotocore-globalaccelerator>=13.3.0, <13.4.0"],
        "glue": ["types-aiobotocore-glue>=13.3.0, <13.4.0"],
        "grafana": ["types-aiobotocore-grafana>=13.3.0, <13.4.0"],
        "greengrass": ["types-aiobotocore-greengrass>=13.3.0, <13.4.0"],
        "greengrassv2": ["types-aiobotocore-greengrassv2>=13.3.0, <13.4.0"],
        "groundstation": ["types-aiobotocore-groundstation>=13.3.0, <13.4.0"],
        "guardduty": ["types-aiobotocore-guardduty>=13.3.0, <13.4.0"],
        "health": ["types-aiobotocore-health>=13.3.0, <13.4.0"],
        "healthlake": ["types-aiobotocore-healthlake>=13.3.0, <13.4.0"],
        "iam": ["types-aiobotocore-iam>=13.3.0, <13.4.0"],
        "identitystore": ["types-aiobotocore-identitystore>=13.3.0, <13.4.0"],
        "imagebuilder": ["types-aiobotocore-imagebuilder>=13.3.0, <13.4.0"],
        "importexport": ["types-aiobotocore-importexport>=13.3.0, <13.4.0"],
        "inspector": ["types-aiobotocore-inspector>=13.3.0, <13.4.0"],
        "inspector-scan": ["types-aiobotocore-inspector-scan>=13.3.0, <13.4.0"],
        "inspector2": ["types-aiobotocore-inspector2>=13.3.0, <13.4.0"],
        "internetmonitor": ["types-aiobotocore-internetmonitor>=13.3.0, <13.4.0"],
        "invoicing": ["types-aiobotocore-invoicing>=13.3.0, <13.4.0"],
        "iot": ["types-aiobotocore-iot>=13.3.0, <13.4.0"],
        "iot-data": ["types-aiobotocore-iot-data>=13.3.0, <13.4.0"],
        "iot-jobs-data": ["types-aiobotocore-iot-jobs-data>=13.3.0, <13.4.0"],
        "iot1click-devices": ["types-aiobotocore-iot1click-devices>=13.3.0, <13.4.0"],
        "iot1click-projects": ["types-aiobotocore-iot1click-projects>=13.3.0, <13.4.0"],
        "iotanalytics": ["types-aiobotocore-iotanalytics>=13.3.0, <13.4.0"],
        "iotdeviceadvisor": ["types-aiobotocore-iotdeviceadvisor>=13.3.0, <13.4.0"],
        "iotevents": ["types-aiobotocore-iotevents>=13.3.0, <13.4.0"],
        "iotevents-data": ["types-aiobotocore-iotevents-data>=13.3.0, <13.4.0"],
        "iotfleethub": ["types-aiobotocore-iotfleethub>=13.3.0, <13.4.0"],
        "iotfleetwise": ["types-aiobotocore-iotfleetwise>=13.3.0, <13.4.0"],
        "iotsecuretunneling": ["types-aiobotocore-iotsecuretunneling>=13.3.0, <13.4.0"],
        "iotsitewise": ["types-aiobotocore-iotsitewise>=13.3.0, <13.4.0"],
        "iotthingsgraph": ["types-aiobotocore-iotthingsgraph>=13.3.0, <13.4.0"],
        "iottwinmaker": ["types-aiobotocore-iottwinmaker>=13.3.0, <13.4.0"],
        "iotwireless": ["types-aiobotocore-iotwireless>=13.3.0, <13.4.0"],
        "ivs": ["types-aiobotocore-ivs>=13.3.0, <13.4.0"],
        "ivs-realtime": ["types-aiobotocore-ivs-realtime>=13.3.0, <13.4.0"],
        "ivschat": ["types-aiobotocore-ivschat>=13.3.0, <13.4.0"],
        "kafka": ["types-aiobotocore-kafka>=13.3.0, <13.4.0"],
        "kafkaconnect": ["types-aiobotocore-kafkaconnect>=13.3.0, <13.4.0"],
        "kendra": ["types-aiobotocore-kendra>=13.3.0, <13.4.0"],
        "kendra-ranking": ["types-aiobotocore-kendra-ranking>=13.3.0, <13.4.0"],
        "keyspaces": ["types-aiobotocore-keyspaces>=13.3.0, <13.4.0"],
        "kinesis": ["types-aiobotocore-kinesis>=13.3.0, <13.4.0"],
        "kinesis-video-archived-media": [
            "types-aiobotocore-kinesis-video-archived-media>=13.3.0, <13.4.0"
        ],
        "kinesis-video-media": ["types-aiobotocore-kinesis-video-media>=13.3.0, <13.4.0"],
        "kinesis-video-signaling": ["types-aiobotocore-kinesis-video-signaling>=13.3.0, <13.4.0"],
        "kinesis-video-webrtc-storage": [
            "types-aiobotocore-kinesis-video-webrtc-storage>=13.3.0, <13.4.0"
        ],
        "kinesisanalytics": ["types-aiobotocore-kinesisanalytics>=13.3.0, <13.4.0"],
        "kinesisanalyticsv2": ["types-aiobotocore-kinesisanalyticsv2>=13.3.0, <13.4.0"],
        "kinesisvideo": ["types-aiobotocore-kinesisvideo>=13.3.0, <13.4.0"],
        "kms": ["types-aiobotocore-kms>=13.3.0, <13.4.0"],
        "lakeformation": ["types-aiobotocore-lakeformation>=13.3.0, <13.4.0"],
        "lambda": ["types-aiobotocore-lambda>=13.3.0, <13.4.0"],
        "launch-wizard": ["types-aiobotocore-launch-wizard>=13.3.0, <13.4.0"],
        "lex-models": ["types-aiobotocore-lex-models>=13.3.0, <13.4.0"],
        "lex-runtime": ["types-aiobotocore-lex-runtime>=13.3.0, <13.4.0"],
        "lexv2-models": ["types-aiobotocore-lexv2-models>=13.3.0, <13.4.0"],
        "lexv2-runtime": ["types-aiobotocore-lexv2-runtime>=13.3.0, <13.4.0"],
        "license-manager": ["types-aiobotocore-license-manager>=13.3.0, <13.4.0"],
        "license-manager-linux-subscriptions": [
            "types-aiobotocore-license-manager-linux-subscriptions>=13.3.0, <13.4.0"
        ],
        "license-manager-user-subscriptions": [
            "types-aiobotocore-license-manager-user-subscriptions>=13.3.0, <13.4.0"
        ],
        "lightsail": ["types-aiobotocore-lightsail>=13.3.0, <13.4.0"],
        "location": ["types-aiobotocore-location>=13.3.0, <13.4.0"],
        "logs": ["types-aiobotocore-logs>=13.3.0, <13.4.0"],
        "lookoutequipment": ["types-aiobotocore-lookoutequipment>=13.3.0, <13.4.0"],
        "lookoutmetrics": ["types-aiobotocore-lookoutmetrics>=13.3.0, <13.4.0"],
        "lookoutvision": ["types-aiobotocore-lookoutvision>=13.3.0, <13.4.0"],
        "m2": ["types-aiobotocore-m2>=13.3.0, <13.4.0"],
        "machinelearning": ["types-aiobotocore-machinelearning>=13.3.0, <13.4.0"],
        "macie2": ["types-aiobotocore-macie2>=13.3.0, <13.4.0"],
        "mailmanager": ["types-aiobotocore-mailmanager>=13.3.0, <13.4.0"],
        "managedblockchain": ["types-aiobotocore-managedblockchain>=13.3.0, <13.4.0"],
        "managedblockchain-query": ["types-aiobotocore-managedblockchain-query>=13.3.0, <13.4.0"],
        "marketplace-agreement": ["types-aiobotocore-marketplace-agreement>=13.3.0, <13.4.0"],
        "marketplace-catalog": ["types-aiobotocore-marketplace-catalog>=13.3.0, <13.4.0"],
        "marketplace-deployment": ["types-aiobotocore-marketplace-deployment>=13.3.0, <13.4.0"],
        "marketplace-entitlement": ["types-aiobotocore-marketplace-entitlement>=13.3.0, <13.4.0"],
        "marketplace-reporting": ["types-aiobotocore-marketplace-reporting>=13.3.0, <13.4.0"],
        "marketplacecommerceanalytics": [
            "types-aiobotocore-marketplacecommerceanalytics>=13.3.0, <13.4.0"
        ],
        "mediaconnect": ["types-aiobotocore-mediaconnect>=13.3.0, <13.4.0"],
        "mediaconvert": ["types-aiobotocore-mediaconvert>=13.3.0, <13.4.0"],
        "medialive": ["types-aiobotocore-medialive>=13.3.0, <13.4.0"],
        "mediapackage": ["types-aiobotocore-mediapackage>=13.3.0, <13.4.0"],
        "mediapackage-vod": ["types-aiobotocore-mediapackage-vod>=13.3.0, <13.4.0"],
        "mediapackagev2": ["types-aiobotocore-mediapackagev2>=13.3.0, <13.4.0"],
        "mediastore": ["types-aiobotocore-mediastore>=13.3.0, <13.4.0"],
        "mediastore-data": ["types-aiobotocore-mediastore-data>=13.3.0, <13.4.0"],
        "mediatailor": ["types-aiobotocore-mediatailor>=13.3.0, <13.4.0"],
        "medical-imaging": ["types-aiobotocore-medical-imaging>=13.3.0, <13.4.0"],
        "memorydb": ["types-aiobotocore-memorydb>=13.3.0, <13.4.0"],
        "meteringmarketplace": ["types-aiobotocore-meteringmarketplace>=13.3.0, <13.4.0"],
        "mgh": ["types-aiobotocore-mgh>=13.3.0, <13.4.0"],
        "mgn": ["types-aiobotocore-mgn>=13.3.0, <13.4.0"],
        "migration-hub-refactor-spaces": [
            "types-aiobotocore-migration-hub-refactor-spaces>=13.3.0, <13.4.0"
        ],
        "migrationhub-config": ["types-aiobotocore-migrationhub-config>=13.3.0, <13.4.0"],
        "migrationhuborchestrator": ["types-aiobotocore-migrationhuborchestrator>=13.3.0, <13.4.0"],
        "migrationhubstrategy": ["types-aiobotocore-migrationhubstrategy>=13.3.0, <13.4.0"],
        "mq": ["types-aiobotocore-mq>=13.3.0, <13.4.0"],
        "mturk": ["types-aiobotocore-mturk>=13.3.0, <13.4.0"],
        "mwaa": ["types-aiobotocore-mwaa>=13.3.0, <13.4.0"],
        "neptune": ["types-aiobotocore-neptune>=13.3.0, <13.4.0"],
        "neptune-graph": ["types-aiobotocore-neptune-graph>=13.3.0, <13.4.0"],
        "neptunedata": ["types-aiobotocore-neptunedata>=13.3.0, <13.4.0"],
        "network-firewall": ["types-aiobotocore-network-firewall>=13.3.0, <13.4.0"],
        "networkflowmonitor": ["types-aiobotocore-networkflowmonitor>=13.3.0, <13.4.0"],
        "networkmanager": ["types-aiobotocore-networkmanager>=13.3.0, <13.4.0"],
        "networkmonitor": ["types-aiobotocore-networkmonitor>=13.3.0, <13.4.0"],
        "notifications": ["types-aiobotocore-notifications>=13.3.0, <13.4.0"],
        "notificationscontacts": ["types-aiobotocore-notificationscontacts>=13.3.0, <13.4.0"],
        "oam": ["types-aiobotocore-oam>=13.3.0, <13.4.0"],
        "observabilityadmin": ["types-aiobotocore-observabilityadmin>=13.3.0, <13.4.0"],
        "omics": ["types-aiobotocore-omics>=13.3.0, <13.4.0"],
        "opensearch": ["types-aiobotocore-opensearch>=13.3.0, <13.4.0"],
        "opensearchserverless": ["types-aiobotocore-opensearchserverless>=13.3.0, <13.4.0"],
        "opsworks": ["types-aiobotocore-opsworks>=13.3.0, <13.4.0"],
        "opsworkscm": ["types-aiobotocore-opsworkscm>=13.3.0, <13.4.0"],
        "organizations": ["types-aiobotocore-organizations>=13.3.0, <13.4.0"],
        "osis": ["types-aiobotocore-osis>=13.3.0, <13.4.0"],
        "outposts": ["types-aiobotocore-outposts>=13.3.0, <13.4.0"],
        "panorama": ["types-aiobotocore-panorama>=13.3.0, <13.4.0"],
        "partnercentral-selling": ["types-aiobotocore-partnercentral-selling>=13.3.0, <13.4.0"],
        "payment-cryptography": ["types-aiobotocore-payment-cryptography>=13.3.0, <13.4.0"],
        "payment-cryptography-data": [
            "types-aiobotocore-payment-cryptography-data>=13.3.0, <13.4.0"
        ],
        "pca-connector-ad": ["types-aiobotocore-pca-connector-ad>=13.3.0, <13.4.0"],
        "pca-connector-scep": ["types-aiobotocore-pca-connector-scep>=13.3.0, <13.4.0"],
        "pcs": ["types-aiobotocore-pcs>=13.3.0, <13.4.0"],
        "personalize": ["types-aiobotocore-personalize>=13.3.0, <13.4.0"],
        "personalize-events": ["types-aiobotocore-personalize-events>=13.3.0, <13.4.0"],
        "personalize-runtime": ["types-aiobotocore-personalize-runtime>=13.3.0, <13.4.0"],
        "pi": ["types-aiobotocore-pi>=13.3.0, <13.4.0"],
        "pinpoint": ["types-aiobotocore-pinpoint>=13.3.0, <13.4.0"],
        "pinpoint-email": ["types-aiobotocore-pinpoint-email>=13.3.0, <13.4.0"],
        "pinpoint-sms-voice": ["types-aiobotocore-pinpoint-sms-voice>=13.3.0, <13.4.0"],
        "pinpoint-sms-voice-v2": ["types-aiobotocore-pinpoint-sms-voice-v2>=13.3.0, <13.4.0"],
        "pipes": ["types-aiobotocore-pipes>=13.3.0, <13.4.0"],
        "polly": ["types-aiobotocore-polly>=13.3.0, <13.4.0"],
        "pricing": ["types-aiobotocore-pricing>=13.3.0, <13.4.0"],
        "privatenetworks": ["types-aiobotocore-privatenetworks>=13.3.0, <13.4.0"],
        "proton": ["types-aiobotocore-proton>=13.3.0, <13.4.0"],
        "qapps": ["types-aiobotocore-qapps>=13.3.0, <13.4.0"],
        "qbusiness": ["types-aiobotocore-qbusiness>=13.3.0, <13.4.0"],
        "qconnect": ["types-aiobotocore-qconnect>=13.3.0, <13.4.0"],
        "qldb": ["types-aiobotocore-qldb>=13.3.0, <13.4.0"],
        "qldb-session": ["types-aiobotocore-qldb-session>=13.3.0, <13.4.0"],
        "quicksight": ["types-aiobotocore-quicksight>=13.3.0, <13.4.0"],
        "ram": ["types-aiobotocore-ram>=13.3.0, <13.4.0"],
        "rbin": ["types-aiobotocore-rbin>=13.3.0, <13.4.0"],
        "rds": ["types-aiobotocore-rds>=13.3.0, <13.4.0"],
        "rds-data": ["types-aiobotocore-rds-data>=13.3.0, <13.4.0"],
        "redshift": ["types-aiobotocore-redshift>=13.3.0, <13.4.0"],
        "redshift-data": ["types-aiobotocore-redshift-data>=13.3.0, <13.4.0"],
        "redshift-serverless": ["types-aiobotocore-redshift-serverless>=13.3.0, <13.4.0"],
        "rekognition": ["types-aiobotocore-rekognition>=13.3.0, <13.4.0"],
        "repostspace": ["types-aiobotocore-repostspace>=13.3.0, <13.4.0"],
        "resiliencehub": ["types-aiobotocore-resiliencehub>=13.3.0, <13.4.0"],
        "resource-explorer-2": ["types-aiobotocore-resource-explorer-2>=13.3.0, <13.4.0"],
        "resource-groups": ["types-aiobotocore-resource-groups>=13.3.0, <13.4.0"],
        "resourcegroupstaggingapi": ["types-aiobotocore-resourcegroupstaggingapi>=13.3.0, <13.4.0"],
        "robomaker": ["types-aiobotocore-robomaker>=13.3.0, <13.4.0"],
        "rolesanywhere": ["types-aiobotocore-rolesanywhere>=13.3.0, <13.4.0"],
        "route53": ["types-aiobotocore-route53>=13.3.0, <13.4.0"],
        "route53-recovery-cluster": ["types-aiobotocore-route53-recovery-cluster>=13.3.0, <13.4.0"],
        "route53-recovery-control-config": [
            "types-aiobotocore-route53-recovery-control-config>=13.3.0, <13.4.0"
        ],
        "route53-recovery-readiness": [
            "types-aiobotocore-route53-recovery-readiness>=13.3.0, <13.4.0"
        ],
        "route53domains": ["types-aiobotocore-route53domains>=13.3.0, <13.4.0"],
        "route53profiles": ["types-aiobotocore-route53profiles>=13.3.0, <13.4.0"],
        "route53resolver": ["types-aiobotocore-route53resolver>=13.3.0, <13.4.0"],
        "rum": ["types-aiobotocore-rum>=13.3.0, <13.4.0"],
        "s3": ["types-aiobotocore-s3>=13.3.0, <13.4.0"],
        "s3control": ["types-aiobotocore-s3control>=13.3.0, <13.4.0"],
        "s3outposts": ["types-aiobotocore-s3outposts>=13.3.0, <13.4.0"],
        "s3tables": ["types-aiobotocore-s3tables>=13.3.0, <13.4.0"],
        "sagemaker": ["types-aiobotocore-sagemaker>=13.3.0, <13.4.0"],
        "sagemaker-a2i-runtime": ["types-aiobotocore-sagemaker-a2i-runtime>=13.3.0, <13.4.0"],
        "sagemaker-edge": ["types-aiobotocore-sagemaker-edge>=13.3.0, <13.4.0"],
        "sagemaker-featurestore-runtime": [
            "types-aiobotocore-sagemaker-featurestore-runtime>=13.3.0, <13.4.0"
        ],
        "sagemaker-geospatial": ["types-aiobotocore-sagemaker-geospatial>=13.3.0, <13.4.0"],
        "sagemaker-metrics": ["types-aiobotocore-sagemaker-metrics>=13.3.0, <13.4.0"],
        "sagemaker-runtime": ["types-aiobotocore-sagemaker-runtime>=13.3.0, <13.4.0"],
        "savingsplans": ["types-aiobotocore-savingsplans>=13.3.0, <13.4.0"],
        "scheduler": ["types-aiobotocore-scheduler>=13.3.0, <13.4.0"],
        "schemas": ["types-aiobotocore-schemas>=13.3.0, <13.4.0"],
        "sdb": ["types-aiobotocore-sdb>=13.3.0, <13.4.0"],
        "secretsmanager": ["types-aiobotocore-secretsmanager>=13.3.0, <13.4.0"],
        "security-ir": ["types-aiobotocore-security-ir>=13.3.0, <13.4.0"],
        "securityhub": ["types-aiobotocore-securityhub>=13.3.0, <13.4.0"],
        "securitylake": ["types-aiobotocore-securitylake>=13.3.0, <13.4.0"],
        "serverlessrepo": ["types-aiobotocore-serverlessrepo>=13.3.0, <13.4.0"],
        "service-quotas": ["types-aiobotocore-service-quotas>=13.3.0, <13.4.0"],
        "servicecatalog": ["types-aiobotocore-servicecatalog>=13.3.0, <13.4.0"],
        "servicecatalog-appregistry": [
            "types-aiobotocore-servicecatalog-appregistry>=13.3.0, <13.4.0"
        ],
        "servicediscovery": ["types-aiobotocore-servicediscovery>=13.3.0, <13.4.0"],
        "ses": ["types-aiobotocore-ses>=13.3.0, <13.4.0"],
        "sesv2": ["types-aiobotocore-sesv2>=13.3.0, <13.4.0"],
        "shield": ["types-aiobotocore-shield>=13.3.0, <13.4.0"],
        "signer": ["types-aiobotocore-signer>=13.3.0, <13.4.0"],
        "simspaceweaver": ["types-aiobotocore-simspaceweaver>=13.3.0, <13.4.0"],
        "sms": ["types-aiobotocore-sms>=13.3.0, <13.4.0"],
        "sms-voice": ["types-aiobotocore-sms-voice>=13.3.0, <13.4.0"],
        "snow-device-management": ["types-aiobotocore-snow-device-management>=13.3.0, <13.4.0"],
        "snowball": ["types-aiobotocore-snowball>=13.3.0, <13.4.0"],
        "sns": ["types-aiobotocore-sns>=13.3.0, <13.4.0"],
        "socialmessaging": ["types-aiobotocore-socialmessaging>=13.3.0, <13.4.0"],
        "sqs": ["types-aiobotocore-sqs>=13.3.0, <13.4.0"],
        "ssm": ["types-aiobotocore-ssm>=13.3.0, <13.4.0"],
        "ssm-contacts": ["types-aiobotocore-ssm-contacts>=13.3.0, <13.4.0"],
        "ssm-incidents": ["types-aiobotocore-ssm-incidents>=13.3.0, <13.4.0"],
        "ssm-quicksetup": ["types-aiobotocore-ssm-quicksetup>=13.3.0, <13.4.0"],
        "ssm-sap": ["types-aiobotocore-ssm-sap>=13.3.0, <13.4.0"],
        "sso": ["types-aiobotocore-sso>=13.3.0, <13.4.0"],
        "sso-admin": ["types-aiobotocore-sso-admin>=13.3.0, <13.4.0"],
        "sso-oidc": ["types-aiobotocore-sso-oidc>=13.3.0, <13.4.0"],
        "stepfunctions": ["types-aiobotocore-stepfunctions>=13.3.0, <13.4.0"],
        "storagegateway": ["types-aiobotocore-storagegateway>=13.3.0, <13.4.0"],
        "sts": ["types-aiobotocore-sts>=13.3.0, <13.4.0"],
        "supplychain": ["types-aiobotocore-supplychain>=13.3.0, <13.4.0"],
        "support": ["types-aiobotocore-support>=13.3.0, <13.4.0"],
        "support-app": ["types-aiobotocore-support-app>=13.3.0, <13.4.0"],
        "swf": ["types-aiobotocore-swf>=13.3.0, <13.4.0"],
        "synthetics": ["types-aiobotocore-synthetics>=13.3.0, <13.4.0"],
        "taxsettings": ["types-aiobotocore-taxsettings>=13.3.0, <13.4.0"],
        "textract": ["types-aiobotocore-textract>=13.3.0, <13.4.0"],
        "timestream-influxdb": ["types-aiobotocore-timestream-influxdb>=13.3.0, <13.4.0"],
        "timestream-query": ["types-aiobotocore-timestream-query>=13.3.0, <13.4.0"],
        "timestream-write": ["types-aiobotocore-timestream-write>=13.3.0, <13.4.0"],
        "tnb": ["types-aiobotocore-tnb>=13.3.0, <13.4.0"],
        "transcribe": ["types-aiobotocore-transcribe>=13.3.0, <13.4.0"],
        "transfer": ["types-aiobotocore-transfer>=13.3.0, <13.4.0"],
        "translate": ["types-aiobotocore-translate>=13.3.0, <13.4.0"],
        "trustedadvisor": ["types-aiobotocore-trustedadvisor>=13.3.0, <13.4.0"],
        "verifiedpermissions": ["types-aiobotocore-verifiedpermissions>=13.3.0, <13.4.0"],
        "voice-id": ["types-aiobotocore-voice-id>=13.3.0, <13.4.0"],
        "vpc-lattice": ["types-aiobotocore-vpc-lattice>=13.3.0, <13.4.0"],
        "waf": ["types-aiobotocore-waf>=13.3.0, <13.4.0"],
        "waf-regional": ["types-aiobotocore-waf-regional>=13.3.0, <13.4.0"],
        "wafv2": ["types-aiobotocore-wafv2>=13.3.0, <13.4.0"],
        "wellarchitected": ["types-aiobotocore-wellarchitected>=13.3.0, <13.4.0"],
        "wisdom": ["types-aiobotocore-wisdom>=13.3.0, <13.4.0"],
        "workdocs": ["types-aiobotocore-workdocs>=13.3.0, <13.4.0"],
        "workmail": ["types-aiobotocore-workmail>=13.3.0, <13.4.0"],
        "workmailmessageflow": ["types-aiobotocore-workmailmessageflow>=13.3.0, <13.4.0"],
        "workspaces": ["types-aiobotocore-workspaces>=13.3.0, <13.4.0"],
        "workspaces-thin-client": ["types-aiobotocore-workspaces-thin-client>=13.3.0, <13.4.0"],
        "workspaces-web": ["types-aiobotocore-workspaces-web>=13.3.0, <13.4.0"],
        "xray": ["types-aiobotocore-xray>=13.3.0, <13.4.0"],
    },
    zip_safe=False,
)
